==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/YesterdayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YesterdayExpressionDescription } from "./YesterdayExpressionDescription";
/**
 * @hidden
 */
export let YesterdayExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class YesterdayExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (YesterdayExpressionDescriptionMetadata.a == null) {
                YesterdayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                YesterdayExpressionDescriptionMetadata.c(YesterdayExpressionDescriptionMetadata.a);
            }
            if (a.j(YesterdayExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(YesterdayExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            YesterdayExpressionDescriptionMetadata.b(a);
            a.aa("YesterdayExpression", () => new YesterdayExpressionDescription());
            a.z("YesterdayExpression", YesterdayExpressionDescriptionMetadata.a);
        }
    }
    YesterdayExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(YesterdayExpressionDescriptionMetadata, 'YesterdayExpressionDescriptionMetadata');
    YesterdayExpressionDescriptionMetadata.a = null;
    return YesterdayExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/YesterdayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YesterdayExpressionDescription } from "./YesterdayExpressionDescription";
/**
 * @hidden
 */
export let YesterdayExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class YesterdayExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (YesterdayExpressionDescriptionMetadata.a == null) {
                YesterdayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                YesterdayExpressionDescriptionMetadata.c(YesterdayExpressionDescriptionMetadata.a);
            }
            if (a.k(YesterdayExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(YesterdayExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            YesterdayExpressionDescriptionMetadata.b(a);
            a.ac("YesterdayExpression", () => new YesterdayExpressionDescription());
            a.ab("YesterdayExpression", YesterdayExpressionDescriptionMetadata.a);
        }
    }
    YesterdayExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(YesterdayExpressionDescriptionMetadata, 'YesterdayExpressionDescriptionMetadata');
    YesterdayExpressionDescriptionMetadata.a = null;
    return YesterdayExpressionDescriptionMetadata;
})();
